## diff_classifier
[![status](http://joss.theoj.org/papers/003901de75c26c1dd3f060043249bc4f/status.svg)](http://joss.theoj.org/papers/003901de75c26c1dd3f060043249bc4f)
[![Build Status](https://travis-ci.org/ccurtis7/diff_classifier.svg?branch=master)](https://travis-ci.org/ccurtis7/diff_classifier)
[![Coverage Status](https://coveralls.io/repos/github/ccurtis7/diff_classifier/badge.svg)](https://coveralls.io/github/ccurtis7/diff_classifier)
[![Scrutinizer Code Quality](https://img.shields.io/scrutinizer/g/ccurtis7/diff_classifier.svg)](https://scrutinizer-ci.com/g/ccurtis7/diff_classifier/?branch=master)
[![Average time to resolve an issue](http://isitmaintained.com/badge/resolution/ccurtis7/diff_classifier.svg)](http://isitmaintained.com/project/ccurtis7/diff_classifier "Average time to resolve an issue")
[![Percentage of issues still open](http://isitmaintained.com/badge/open/ccurtis7/diff_classifier.svg)](http://isitmaintained.com/project/ccurtis7/diff_classifier "Percentage of issues still open")
[![GitHub license](
https://img.shields.io/github/license/ccurtis7/diff_classifier.svg)](https://github.com/ccurtis7/diff_classifier/blob/master/LICENSE)
[![DOI](https://zenodo.org/badge/116980257.svg)](https://zenodo.org/badge/latestdoi/116980257)


diff_classifier is a python package for analyzing and visualizing 2D
nanoparticle trajectory data from multi-particle tracking analysis.  The package
utilizes the ImageJ package Trackmate for tracking analysis, and Cloudknot for
parallelization on AWS.

<p align="center"><img src="doc/source/_static/summary.png"
alt="diff_classifier" height="300" title="diff_classifier"/></p>


This is the diff_classifier development site.  You can view the source code and
file new issues. If you are just getting started, you should look at the
[diff_classifier documentation](https://Nance-Lab.github.io/diff_classifier/)

## Contributing

Contributions are welcome! Diff_classifier is open source, built on open source,
and we love any input, suggestions, and problems.

[Guidelines](CONTRIBUTING.md) for contributing are included for your convenience.

## Credits

This package was created with [shablona](https://github.com/uwescience/shablona).

Guidelines for contributions were based off the
[CONTRIBUTIONS](https://github.com/richford/cloudknot/blob/master/CONTRIBUTING.md)
file developed by [Adam Richie-Halford](https://github.com/richford).
